package com.ruoyi.project.intact.his.service.impl;

import java.util.List;

import com.ruoyi.project.intact.his.domain.TIntactHiGj;
import com.ruoyi.project.intact.his.domain.TIntactHiPump;
import com.ruoyi.project.intact.his.mapper.TIntactHiGjMapper;
import com.ruoyi.project.intact.his.service.ITIntactHiGjService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 设备完整性-管件台账变更历史记录Service业务层处理
 *
 * @author ruoyi
 * @date 2022-06-29
 */
@Service
public class TIntactHiGjServiceImpl implements ITIntactHiGjService
{
    @Autowired
    private TIntactHiGjMapper tIntactHiGjMapper;

    /**
     * 查询设备完整性-管件台账变更历史记录
     *
     * @param id 设备完整性-管件台账变更历史记录ID
     * @return 设备完整性-管件台账变更历史记录
     */
    @Override
    public TIntactHiGj selectTIntactHiGjById(Long id)
    {
        return tIntactHiGjMapper.selectTIntactHiGjById(id);
    }

    /**
     * 查询设备完整性-管件台账变更历史记录列表
     *
     * @param tIntactHiGj 设备完整性-管件台账变更历史记录
     * @return 设备完整性-管件台账变更历史记录
     */
    @Override
    public List<TIntactHiGj> selectTIntactHiGjList(TIntactHiGj tIntactHiGj)
    {
        return tIntactHiGjMapper.selectTIntactHiGjList(tIntactHiGj);
    }


    @Override
    public List<TIntactHiGj> selectTIntactHiGjByReform(Long devId) {
        return tIntactHiGjMapper.selectTIntactHiGjByReform(devId);
    }

    /**
     * 新增设备完整性-管件台账变更历史记录
     *
     * @param tIntactHiGj 设备完整性-管件台账变更历史记录
     * @return 结果
     */
    @Override
    public int insertTIntactHiGj(TIntactHiGj tIntactHiGj)
    {
        return tIntactHiGjMapper.insertTIntactHiGj(tIntactHiGj);
    }

    /**
     * 修改设备完整性-管件台账变更历史记录
     *
     * @param tIntactHiGj 设备完整性-管件台账变更历史记录
     * @return 结果
     */
    @Override
    public int updateTIntactHiGj(TIntactHiGj tIntactHiGj)
    {
        return tIntactHiGjMapper.updateTIntactHiGj(tIntactHiGj);
    }

    /**
     * 批量删除设备完整性-管件台账变更历史记录
     *
     * @param ids 需要删除的设备完整性-管件台账变更历史记录ID
     * @return 结果
     */
    @Override
    public int deleteTIntactHiGjByIds(Long[] ids)
    {
        return tIntactHiGjMapper.deleteTIntactHiGjByIds(ids);
    }

    /**
     * 删除设备完整性-管件台账变更历史记录信息
     *
     * @param id 设备完整性-管件台账变更历史记录ID
     * @return 结果
     */

    @Override
    public int deleteTIntactHiGjById(Long id)
    {
        return tIntactHiGjMapper.deleteTIntactHiGjById(id);
    }
    /**
     * 通过devId删除修改记录
     * @param devId
     * @return
     */
    @Override
    public int deleteTIntactHiGjByDevId(Long devId) {
        return tIntactHiGjMapper.deleteTIntactHiGjByDevId(devId);
    }
}
